{pkgs, ...}: {
  imports = [
    ../../modules/applications/alacritty.nix
    ../../modules/applications/sioyek.nix

    ../../modules/zsh.nix
    ../../modules/zellij.nix
    ../../modules/dev.nix
    ../../modules/emacs.nix
    ../../modules/git.nix
    ../../modules/fonts.nix
    ../../modules/latex.nix
    ../../modules/nvim.nix
    # ../../modules/sketchybar.nix
    ../../modules/vscode.nix
  ];

  home.packages = with pkgs; [
    bitwarden-cli
    firebird-emu
    git-credential-oauth
  ];

  programs.zsh = {
    # Needed for nix-shell to have the correct bash version
    profileExtra = ''
      PATH=/run/current-system/sw/bin:$PATH
    '';
    prezto.pmodules = [
      "osx"
    ];
  };

  # iterm2 integration
  home.file = {
    ".zprezto/contrib/zsh-iterm2".source = pkgs.fetchFromGitHub {
      owner = "laggardkernel";
      repo = "zsh-iterm2";
      rev = "6f9d8951b3330593ceb66972a71a067793b0981e";
      hash = "sha256-wh9Rltajlb5FlxW1WKGdufnPkikn4gRJZ+fbPO3rVWc=";
    };
  };

  programs.git.extraConfig.credential.helper = [
    "osxkeychain"
    "oauth"
  ];

  # Let Home Manager install and manage itself.
  programs.home-manager.enable = true;

  # Home Manager needs a bit of information about you and the
  # paths it should manage.
  home.username = "michael";
  home.homeDirectory = "/Users/michael";

  # This value determines the Home Manager release that your
  # configuration is compatible with. This helps avoid breakage
  # when a new Home Manager release introduces backwards
  # incompatible changes.
  #
  # You can update Home Manager without changing this value. See
  # the Home Manager release notes for a list of state version
  # changes in each release.
  home.stateVersion = "22.05";
}
